@@ -250,7 +250,7 @@ class Sublist(list):
         :return: Samples object
         """
 
-        arr = np.array(self)
+        arr = np.array(list(range(len(self))))
 
         if num >= len(self):
             return self
@@ -261,7 +261,7 @@ class Sublist(list):
             return Sublist(temp)
 
         else:
-            return Sublist(np.random.choice(arr, size=num, replace=False))
+            return Sublist(np.random.choice(arr, size=num, replace=False).tolist())
 
     def tuple_by_pairs(self):
         """
