@@ -2,6 +2,8 @@ import numpy as np
 from geosoup.common import Handler, Opt, Sublist
 from geosoup.exceptions import ImageProcessingError, ObjectNotFound
 import warnings
+import random
+import time
 import json
 from osgeo import gdal, gdal_array, ogr, osr, gdalconst
 np.set_printoptions(suppress=True)
@@ -340,11 +342,13 @@ class Raster(object):
 
     def read_array(self,
                    offsets=None,
-                   band_order=None):
+                   band_order=None,
+                   n_tries=5):
         """
         Method to read raster array with offsets and a specific band order
         :param offsets: tuple or list - (xoffset, yoffset, xcount, ycount)
         :param band_order: order of bands to read
+        :param n_tries: number of tries after read error
         """
 
         if not self.init:
@@ -373,11 +377,24 @@ class Raster(object):
 
         # read array and store the band values and name in array
         for i, b in enumerate(band_order):
-            if self.array_offsets is None:
-                array3d[i, :, :] = fileptr.GetRasterBand(b + 1).ReadAsArray()
-            else:
-                array3d[i, :, :] = fileptr.GetRasterBand(b + 1).ReadAsArray(*self.array_offsets,
-                                                                            resample_alg=gdalconst.GRA_NearestNeighbour)
+            read_success = True
+            for i_try in range(n_tries):
+                try:
+                    if self.array_offsets is None:
+                        array3d[i, :, :] = fileptr.GetRasterBand(b + 1).ReadAsArray()
+                    else:
+                        array3d[i, :, :] = fileptr.GetRasterBand(b + 1).ReadAsArray(*self.array_offsets,
+                                                                                    resample_alg=
+                                                                                    gdalconst.GRA_NearestNeighbour)
+                    break
+                except RuntimeError as e:
+                    read_success = False
+                    Opt.cprint(e)
+                    Opt.cprint('Retrying failed read... attempt {}'.format(i_try + 1))
+                    time.sleep(random.random() + 1.0)
+
+            if not read_success:
+                array3d[i, :, :] = self.nodatavalue
 
         if (self.shape[0] == 1) and (len(array3d.shape) > 2):
             self.array = array3d.reshape([self.array_offsets[3],
@@ -1015,13 +1032,15 @@ class Raster(object):
                  block_coords=None,
                  finite_only=True,
                  edge_buffer=0,
-                 nan_replacement=None):
+                 nan_replacement=None,
+                 n_tries=5):
         """
         Method to get raster numpy array of a tile
         :param bands: bands to get in the array, index starts from one. (default: all)
         :param finite_only:  If only finite values should be returned
         :param edge_buffer: Number of extra pixels to retrieve further out from the edges (default: 0)
         :param nan_replacement: replacement for NAN values
+        :param n_tries: Number of randomized tries when reading raster is errored out
         :param block_coords: coordinates of tile to retrieve in image/array coords
                              format is (upperleft_x, upperleft_y, tile_cols, tile_rows)
                              upperleft_x and upperleft_y are array coordinates starting at 0,
@@ -1075,25 +1094,31 @@ class Raster(object):
                             tile_rows + (2 * edge_buffer - pixel_deficit[1] + pixel_deficit[3]),
                             tile_cols + (2 * edge_buffer - pixel_deficit[0] + pixel_deficit[2])]
 
-        if len(bands) == 1:
-            temp_band = self.datasource.GetRasterBand(bands[0])
-            tile_arr = temp_band.ReadAsArray(*new_block_coords)
-            tile_arr = tile_arr[np.newaxis, :, :]
+        tile_arr = np.zeros((len(bands),
+                             new_block_coords[3],
+                             new_block_coords[2]),
+                            gdal_array.GDALTypeCodeToNumericTypeCode(self.dtype))
 
-        else:
-            tile_arr = np.zeros((len(bands),
-                                 new_block_coords[3],
-                                 new_block_coords[2]),
-                                gdal_array.GDALTypeCodeToNumericTypeCode(self.dtype))
+        for jj, band in enumerate(bands):
+            read_success = True
+            for i_try in range(n_tries):
+                try:
+                    temp_band = self.datasource.GetRasterBand(band)
+                    tile_arr[jj, :, :] = temp_band.ReadAsArray(*new_block_coords)
+                    break
+                except RuntimeError as e:
+                    read_success = False
+                    Opt.cprint(e)
+                    Opt.cprint('Retrying failed read...attempt {}'.format(i_try + 1))
+                    time.sleep(random.random() + 1.0)
 
-            for jj, band in enumerate(bands):
-                temp_band = self.datasource.GetRasterBand(band)
-                tile_arr[jj, :, :] = temp_band.ReadAsArray(*new_block_coords)
+            if not read_success:
+                tile_arr[jj, :, :] = self.nodatavalue
 
-            if finite_only:
-                if np.isnan(tile_arr).any() or np.isinf(tile_arr).any():
-                    tile_arr[np.isnan(tile_arr)] = nan_replacement
-                    tile_arr[np.isinf(tile_arr)] = nan_replacement
+        if finite_only:
+            if np.isnan(tile_arr).any() or np.isinf(tile_arr).any():
+                tile_arr[np.isnan(tile_arr)] = nan_replacement
+                tile_arr[np.isinf(tile_arr)] = nan_replacement
 
         return tile_arr
 
